## Copyright (C) 2018 jdonoghue
## 
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see
## <https://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {} {} writePWMVoltage (@var{ar}, @var{pin}, @var{voltage})
## Emulate an approximate voltage out of pin @var{pin} using PWM.
##
## @var{ar} - connected arduino object
## @var{pin} - pin to write to.
## @var{voltage} - voltage to emulate with PWM, between 0 - 5.0
##
## Example usage:
## @example
## a = arduino();
## writePWMVoltage(a,'D5',1.0);
## @end example
##
## @seealso{arduino, writePWMDutyCycle}
## @end deftypefn

function writePWMVoltage (obj, pin, value)
  if nargin < 3
    error ("@arduino.writePWMVoltage: expected pin name and value");
  endif

  # TODO: need look at board type for what voltage range is allowed
  # and convert
  if !isnumeric(value) || value < 0 or value > 5.0
    error('writePWMVoltage: value must be between 0 and 5");
  endif

  $ assuming here for now 0 .. 5V is linear to 0 - 100% pwm
  val = value/5.0;
  writePWMDutyCycle(obj, pin, val);
  
endfunction
